@@ -1,7 +1,7 @@
 NAME = 'redis_kernel'
-VERSION = '0.2'
+VERSION = '0.2.1'
 LANGUAGE = 'redis'
-BANNER = 'redis kernel 0.2'
+BANNER = 'redis kernel 0.2.1'
 DEFAULT_HOST = 'localhost'
 DEFAULT_PORT = '6379'
 DISPLAY_NAME = 'Redis'
